@@ -1,5 +1,5 @@
 /*******************************************************************************
- *  Copyright (c) 2000, 2019 IBM Corporation and others.
+ *  Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  *  This program and the accompanying materials
  *  are made available under the terms of the Eclipse Public License 2.0
@@ -63,6 +63,7 @@ public class JavaProjectHelper {
 	public static final String JAVA_SE_1_7_EE_NAME = "JavaSE-1.7";
 	public static final String JAVA_SE_1_8_EE_NAME = "JavaSE-1.8";
 	public static final String JAVA_SE_9_EE_NAME = "JavaSE-9";
+	public static final String JAVA_SE_16_EE_NAME = "JavaSE-16";
 
 	/**
 	 * path to the test src for 'testprograms'
@@ -85,6 +86,10 @@ public class JavaProjectHelper {
 	 * path to the 9 test source
 	 */
 	public static final IPath TEST_9_SRC_DIR = new Path("java9");
+	/**
+	 * path to the 16 test source
+	 */
+	public static final IPath TEST_16_SRC_DIR = new Path("java16_");
 
 	/**
 	 * path to the compiler error java file
@@ -138,6 +143,15 @@ public class JavaProjectHelper {
 		return isCompatible(5);
 	}
 
+	/**
+	 * Returns if the currently running VM is version compatible with Java 16
+	 *
+	 * @return <code>true</code> if a Java 16 (or greater) VM is running <code>false</code> otherwise
+	 */
+	public static boolean isJava16_Compatible() {
+		return isCompatible(16);
+	}
+
 	/**
 	 * Returns if the current running system is compatible with the given Java minor version
 	 *
