@@ -72,7 +72,7 @@ public class JavaBreakpointListenerTests extends AbstractDebugTest implements IJ
 	/**
 	 * Used to test breakpoint install/suspend voting.
 	 */
-	class SuspendVoter implements IJavaBreakpointListener {
+	static class SuspendVoter implements IJavaBreakpointListener {
 
 		int fVote;
 		IJavaBreakpoint fTheBreakpoint;
@@ -782,7 +782,7 @@ public class JavaBreakpointListenerTests extends AbstractDebugTest implements IJ
 		bp.addBreakpointListener("org.eclipse.jdt.debug.tests.evalListener");
 		EvalualtionBreakpointListener.reset();
 		EvalualtionBreakpointListener.PROJECT = get14Project();
-		EvalualtionBreakpointListener.EXPRESSION = "return new Integer(i);";
+		EvalualtionBreakpointListener.EXPRESSION = "return Integer.valueOf(i);";
 		EvalualtionBreakpointListener.VOTE = IJavaBreakpointListener.SUSPEND;
 
 		IJavaThread thread= null;
@@ -798,7 +798,7 @@ public class JavaBreakpointListenerTests extends AbstractDebugTest implements IJ
 				IVariable variable = variables[i];
 				if (variable.getName().equals("value")) {
 					IValue iValue = variable.getValue();
-					assertTrue("Should be an int", iValue.getReferenceTypeName().equals("int"));
+					assertEquals("Should be an int", "int", iValue.getReferenceTypeName());
 					assertTrue("Should be a primitive", iValue instanceof IJavaPrimitiveValue);
 					int intValue = ((IJavaPrimitiveValue)iValue).getIntValue();
 					assertEquals("Wrong value", 0, intValue);
@@ -851,7 +851,7 @@ public class JavaBreakpointListenerTests extends AbstractDebugTest implements IJ
 		second.addBreakpointListener("org.eclipse.jdt.debug.tests.evalListener");
 		EvalualtionBreakpointListener.reset();
 		EvalualtionBreakpointListener.PROJECT = get14Project();
-		EvalualtionBreakpointListener.EXPRESSION = "return new Integer(sum);";
+		EvalualtionBreakpointListener.EXPRESSION = "return Integer.valueOf(sum);";
 		EvalualtionBreakpointListener.VOTE = IJavaBreakpointListener.DONT_SUSPEND;
 		EvalualtionBreakpointListener.RESULT = null;
 
@@ -876,7 +876,7 @@ public class JavaBreakpointListenerTests extends AbstractDebugTest implements IJ
 				IVariable variable = variables[i];
 				if (variable.getName().equals("value")) {
 					IValue iValue = variable.getValue();
-					assertTrue("Should be an int", iValue.getReferenceTypeName().equals("int"));
+					assertEquals("Should be an int", "int", iValue.getReferenceTypeName());
 					assertTrue("Should be a primitive", iValue instanceof IJavaPrimitiveValue);
 					int intValue = ((IJavaPrimitiveValue)iValue).getIntValue();
 					assertEquals("Wrong value", 0, intValue);
@@ -904,7 +904,7 @@ public class JavaBreakpointListenerTests extends AbstractDebugTest implements IJ
 		second.addBreakpointListener("org.eclipse.jdt.debug.tests.evalListener");
 		EvalualtionBreakpointListener.reset();
 		EvalualtionBreakpointListener.PROJECT = get14Project();
-		EvalualtionBreakpointListener.EXPRESSION = "return new Integer(sum);";
+		EvalualtionBreakpointListener.EXPRESSION = "return Integer.valueOf(sum);";
 		EvalualtionBreakpointListener.VOTE = IJavaBreakpointListener.SUSPEND;
 		EvalualtionBreakpointListener.RESULT = null;
 
@@ -931,7 +931,7 @@ public class JavaBreakpointListenerTests extends AbstractDebugTest implements IJ
 				IVariable variable = variables[i];
 				if (variable.getName().equals("value")) {
 					IValue iValue = variable.getValue();
-					assertTrue("Should be an int", iValue.getReferenceTypeName().equals("int"));
+					assertEquals("Should be an int", "int", iValue.getReferenceTypeName());
 					assertTrue("Should be a primitive", iValue instanceof IJavaPrimitiveValue);
 					int intValue = ((IJavaPrimitiveValue)iValue).getIntValue();
 					assertEquals("Wrong value", 0, intValue);
