@@ -16,17 +16,17 @@ package org.eclipse.jdt.debug.tests.eval;
 import org.eclipse.debug.core.model.IValue;
 import org.eclipse.jdt.debug.core.IJavaPrimitiveValue;
 
-public class TypeHierarchy_119_1 extends Tests {
+public class TypeHierarchy_68_3 extends Tests {
 	/**
 	 * Constructor for TypeHierarchy.
 	 * @param name
 	 */
-	public TypeHierarchy_119_1(String name) {
+	public TypeHierarchy_68_3(String name) {
 		super(name);
 	}
 
 	public void init() throws Exception {
-		initializeFrame("EvalTypeHierarchyTests", 122, 2, 1);
+		initializeFrame("EvalTypeHierarchyTests", 71, 2, 3);
 	}
 
 	protected void end() throws Exception {
@@ -66,7 +66,7 @@ public class TypeHierarchy_119_1 extends Tests {
 		String typeName = value.getReferenceTypeName();
 		assertEquals("s2 : wrong type : ", "int", typeName);
 		int intValue = ((IJavaPrimitiveValue)value).getIntValue();
-		assertEquals("s2 : wrong result : ", 999, intValue);
+		assertEquals("s2 : wrong result : ", 99, intValue);
 		} finally {
 		end();
 		}
@@ -105,46 +105,7 @@ public class TypeHierarchy_119_1 extends Tests {
 		String typeName = value.getReferenceTypeName();
 		assertEquals("s4 : wrong type : ", "int", typeName);
 		int intValue = ((IJavaPrimitiveValue)value).getIntValue();
-		assertEquals("s4 : wrong result : ", 888, intValue);
-		} finally {
-		end();
-		}
-	}
-
-	public void testEvalNestedTypeTest_m5() throws Throwable {
-		try {
-		init();
-		IValue value = eval("m5()");
-		String typeName = value.getReferenceTypeName();
-		assertEquals("m5 : wrong type : ", "int", typeName);
-		int intValue = ((IJavaPrimitiveValue)value).getIntValue();
-		assertEquals("m5 : wrong result : ", 555, intValue);
-		} finally {
-		end();
-		}
-	}
-
-	public void testEvalNestedTypeTest_m6() throws Throwable {
-		try {
-		init();
-		IValue value = eval("m6()");
-		String typeName = value.getReferenceTypeName();
-		assertEquals("m6 : wrong type : ", "int", typeName);
-		int intValue = ((IJavaPrimitiveValue)value).getIntValue();
-		assertEquals("m6 : wrong result : ", 666, intValue);
-		} finally {
-		end();
-		}
-	}
-
-	public void testEvalNestedTypeTest_s6() throws Throwable {
-		try {
-		init();
-		IValue value = eval("s6()");
-		String typeName = value.getReferenceTypeName();
-		assertEquals("s6 : wrong type : ", "int", typeName);
-		int intValue = ((IJavaPrimitiveValue)value).getIntValue();
-		assertEquals("s6 : wrong result : ", 777, intValue);
+		assertEquals("s4 : wrong result : ", 88, intValue);
 		} finally {
 		end();
 		}
@@ -157,7 +118,7 @@ public class TypeHierarchy_119_1 extends Tests {
 		String typeName = value.getReferenceTypeName();
 		assertEquals("super.m1 : wrong type : ", "int", typeName);
 		int intValue = ((IJavaPrimitiveValue)value).getIntValue();
-		assertEquals("super.m1 : wrong result : ", 11, intValue);
+		assertEquals("super.m1 : wrong result : ", 1, intValue);
 		} finally {
 		end();
 		}
@@ -170,33 +131,7 @@ public class TypeHierarchy_119_1 extends Tests {
 		String typeName = value.getReferenceTypeName();
 		assertEquals("super.m2 : wrong type : ", "int", typeName);
 		int intValue = ((IJavaPrimitiveValue)value).getIntValue();
-		assertEquals("super.m2 : wrong result : ", 22, intValue);
-		} finally {
-		end();
-		}
-	}
-
-	public void testEvalNestedTypeTest_super_m3() throws Throwable {
-		try {
-		init();
-		IValue value = eval("super.m3()");
-		String typeName = value.getReferenceTypeName();
-		assertEquals("super.m3 : wrong type : ", "int", typeName);
-		int intValue = ((IJavaPrimitiveValue)value).getIntValue();
-		assertEquals("super.m3 : wrong result : ", 33, intValue);
-		} finally {
-		end();
-		}
-	}
-
-	public void testEvalNestedTypeTest_super_m4() throws Throwable {
-		try {
-		init();
-		IValue value = eval("super.m4()");
-		String typeName = value.getReferenceTypeName();
-		assertEquals("super.m4 : wrong type : ", "int", typeName);
-		int intValue = ((IJavaPrimitiveValue)value).getIntValue();
-		assertEquals("super.m4 : wrong result : ", 44, intValue);
+		assertEquals("super.m2 : wrong result : ", 2, intValue);
 		} finally {
 		end();
 		}
