@@ -112,7 +112,8 @@ public class EvaluationSourceGenerator {
 		int i ;
 		for (i=0; i < chars.length; i++) {
 			// copy everything before the last statement or if whitespace
-			if (i<= semicolonIndex || Character.isWhitespace(chars[i]) || chars[i] == '}'){
+			if (i<= semicolonIndex || Character.isWhitespace(chars[i]) || chars[i] == '}' 
+					|| (i > 0 && (chars[i - 1] == '}' && (chars[i] == ')' || chars[i] == ',')))) {
 				wordBuffer.append(codeSnippet.charAt(i));
 			}
 			else
@@ -123,15 +124,19 @@ public class EvaluationSourceGenerator {
 		String returnString = "return "; //$NON-NLS-1$
 		int index = codeSnippet.lastIndexOf(returnString);
 		if (index == -1){
-			if (needsReturn(lastSentence))
+			// empty lastSentence means we have statement block above which requires a empty return
+			if (needsReturn(lastSentence)) {
 				wordBuffer.append(returnString);
+			} else if (lastSentence.isBlank()) {
+				wordBuffer.append(returnString + ';');
+			}
 		}
 		else if (index > i){
 			if (!Character.isWhitespace(chars[index-1]) || !(Character.isWhitespace(chars[index+6]) || chars[index+6] == '}')){
 				if (needsReturn(lastSentence))
 					wordBuffer.append(returnString);
 			}
-		} else if (chars[chars.length -1] !='}' && ( i+7 > chars.length || (i + 7 <= chars.length && !codeSnippet.substring(i, i+7).equals(returnString)))){
+		} else if (chars[chars.length -1] !='}' && ( (i+7 > chars.length && lastSentence.length() > 1) || (i + 7 <= chars.length && !codeSnippet.substring(i, i+7).equals(returnString)))){
 			// add return if last statement does not have return
 			if (needsReturn(lastSentence))
 				wordBuffer.append(returnString);
@@ -146,9 +151,15 @@ public class EvaluationSourceGenerator {
 		else if (chars[chars.length -1] !=';' && chars[chars.length -1] =='}'){
 			int j = lastSentence.lastIndexOf('=') ;
 			int k = lastSentence.lastIndexOf("==") ; //$NON-NLS-1$
-			if ( j != -1 && (j!=k))
+			if (j != -1 && (j != k))
 				wordBuffer.append(';');
 		}
+		
+		// make sure last char is not at end of a block before treating this as a statement
+		if (lastSentence.length() <= 1 && needsReturn(wordBuffer.toString())) {
+			wordBuffer.insert(0, returnString).append(' ');
+		}
+		
 		return wordBuffer.toString();
 	}
 
@@ -186,7 +197,9 @@ public class EvaluationSourceGenerator {
 				else if (count == 0 && (token == ITerminalSymbols.TokenNamethrow)){
 					return false;
 				}
-				else if ( count == 0 && (token == ITerminalSymbols.TokenNameif || token == ITerminalSymbols.TokenNamewhile || token == ITerminalSymbols.TokenNamedo)) {
+				else if (count == 0 && (token == ITerminalSymbols.TokenNameif || token == ITerminalSymbols.TokenNamewhile
+						|| token == ITerminalSymbols.TokenNamedo || token == ITerminalSymbols.TokenNamefor || token == ITerminalSymbols.TokenNametry
+						|| token == ITerminalSymbols.TokenNameswitch)) {
 					return false;
 				}
 				else if (count ==1 && (token == ITerminalSymbols.TokenNameLBRACE || token == ITerminalSymbols.TokenNameEQUAL)){
@@ -225,8 +238,20 @@ public class EvaluationSourceGenerator {
 				else if ( (count == 3 || count == 1 ) && token == ITerminalSymbols.TokenNameIdentifier ){
 					 return false;
 				}
-				else {
-					return true;
+				else if (count == 0 && token == ITerminalSymbols.TokenNamereturn) {
+					return false;
+				} else {
+					// ignore and continue the tokens specified here, handling following types of statements
+					// {return i > 0;}, {/**/};{return true;}
+					switch (token) {
+						case ITerminalSymbols.TokenNameLBRACE:
+						case ITerminalSymbols.TokenNameRBRACE:
+						case ITerminalSymbols.TokenNameSEMICOLON:
+							token = scanner.getNextToken();
+							break;
+						default:
+							return true;
+					}
 				}
 
 			}
