@@ -234,7 +234,7 @@ public class JdwpCommandPacket extends JdwpPacket {
 	@Override
 	protected int readSpecificHeaderFields(byte[] bytes, int index) {
 		byte commandSet = bytes[index];
-		fCommand = bytes[index + 1] + (commandSet << 8);
+		fCommand = (bytes[index + 1] & 0xff) + (commandSet << 8);
 		return 2;
 	}
 
@@ -264,8 +264,9 @@ public class JdwpCommandPacket extends JdwpPacket {
 		for (Field field : fields) {
 			if ((field.getModifiers() & Modifier.PUBLIC) == 0
 					|| (field.getModifiers() & Modifier.STATIC) == 0
-					|| (field.getModifiers() & Modifier.FINAL) == 0)
+					|| (field.getModifiers() & Modifier.FINAL) == 0) {
 				continue;
+			}
 
 			try {
 				String name = field.getName();
@@ -274,7 +275,7 @@ public class JdwpCommandPacket extends JdwpPacket {
 					continue;
 				}
 				int value = field.getInt(null);
-				setNames.put(new Integer(value), removePrefix(name));
+				setNames.put(Integer.valueOf(value), removePrefix(name));
 			} catch (IllegalAccessException e) {
 				// Will not occur for own class.
 			} catch (IllegalArgumentException e) {
@@ -303,7 +304,7 @@ public class JdwpCommandPacket extends JdwpPacket {
 				Integer val = (Integer) field.get(null);
 				int value = val.intValue();
 				int set = value >>> 8;
-				String setName = setNames.get(new Integer(set));
+				String setName = setNames.get(Integer.valueOf(set));
 				String entryName = setName + " - " + removePrefix(name); //$NON-NLS-1$
 
 				fgCommandMap.put(val, entryName);
