@@ -20,7 +20,6 @@ import java.util.Map;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IWorkspaceRunnable;
 import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.debug.core.DebugException;
@@ -141,31 +140,25 @@ public class JavaStratumLineBreakpoint extends JavaLineBreakpoint implements
 			final int lineNumber, final int charStart, final int charEnd,
 			final int hitCount, final boolean register, final Map<String, Object> attributes,
 			final String markerType) throws DebugException {
-		IWorkspaceRunnable wr = new IWorkspaceRunnable() {
-			@Override
-			public void run(IProgressMonitor monitor) throws CoreException {
+		IWorkspaceRunnable wr = monitor -> {
 
-				// create the marker
-				setMarker(resource.createMarker(markerType));
-
-				// modify pattern
-				String pattern = classNamePattern;
-				if (pattern != null && pattern.length() == 0) {
-					pattern = null;
-				}
-
-				// add attributes
-				addLineBreakpointAttributes(attributes, getModelIdentifier(),
-						true, lineNumber, charStart, charEnd);
-				addStratumPatternAndHitCount(attributes, stratum, sourceName,
-						sourcePath, pattern, hitCount);
-				// set attributes
-				attributes.put(SUSPEND_POLICY, new Integer(
-						getDefaultSuspendPolicy()));
-				ensureMarker().setAttributes(attributes);
-
-				register(register);
+			// modify pattern
+			String pattern = classNamePattern;
+			if (pattern != null && pattern.length() == 0) {
+				pattern = null;
 			}
+
+			// add attributes
+			addLineBreakpointAttributes(attributes, getModelIdentifier(),
+					true, lineNumber, charStart, charEnd);
+			addStratumPatternAndHitCount(attributes, stratum, sourceName,
+					sourcePath, pattern, hitCount);
+			// set attributes
+			attributes.put(SUSPEND_POLICY, Integer.valueOf(getDefaultSuspendPolicy()));
+			// create the marker
+			setMarker(resource.createMarker(markerType, attributes));
+
+			register(register);
 		};
 		run(getMarkerRule(resource), wr);
 	}
@@ -184,7 +177,7 @@ public class JavaStratumLineBreakpoint extends JavaLineBreakpoint implements
 			attributes.put(SOURCE_PATH, sourcePath);
 		}
 		if (hitCount > 0) {
-			attributes.put(HIT_COUNT, new Integer(hitCount));
+			attributes.put(HIT_COUNT, Integer.valueOf(hitCount));
 			attributes.put(EXPIRED, Boolean.FALSE);
 		}
 	}
@@ -268,14 +261,17 @@ public class JavaStratumLineBreakpoint extends JavaLineBreakpoint implements
 				if (fSuffix[i].length() == 0) {
 					return true;
 				}
-				if (typeName.endsWith(fSuffix[i]))
+				if (typeName.endsWith(fSuffix[i])) {
 					return true;
+				}
 			} else if (fPrefix[i] != null) {
-				if (typeName.startsWith(fPrefix[i]))
+				if (typeName.startsWith(fPrefix[i])) {
 					return true;
+				}
 			} else {
-				if (typeName.startsWith(patterns[i]))
+				if (typeName.startsWith(patterns[i])) {
 					return true;
+				}
 			}
 		}
 
@@ -441,8 +437,9 @@ public class JavaStratumLineBreakpoint extends JavaLineBreakpoint implements
 	}
 
 	public synchronized String[] getTypeNamePatterns() throws CoreException {
-		if (fTypeNamePatterns != null)
+		if (fTypeNamePatterns != null) {
 			return fTypeNamePatterns;
+		}
 
 		String patterns = getPattern();
 
