@@ -18,13 +18,14 @@ package org.eclipse.jdt.internal.launching;
 import java.io.File;
 import java.io.IOException;
 import java.io.InterruptedIOException;
+import java.text.DateFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Date;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
@@ -44,12 +45,10 @@ import org.eclipse.jdi.Bootstrap;
 import org.eclipse.jdt.debug.core.JDIDebugModel;
 import org.eclipse.jdt.launching.IJavaLaunchConfigurationConstants;
 import org.eclipse.jdt.launching.IVMInstall;
-import org.eclipse.jdt.launching.IVMInstall2;
 import org.eclipse.jdt.launching.JavaRuntime;
 import org.eclipse.jdt.launching.SocketUtil;
 import org.eclipse.jdt.launching.VMRunnerConfiguration;
 
-import com.ibm.icu.text.DateFormat;
 import com.sun.jdi.VirtualMachine;
 import com.sun.jdi.connect.Connector;
 import com.sun.jdi.connect.IllegalConnectorArgumentsException;
@@ -113,9 +112,7 @@ public class StandardVMDebugger extends StandardVMRunner {
 		public void run() {
 			try {
 				fVirtualMachine = fConnector.accept(fConnectionMap);
-			} catch (IOException e) {
-				fException = e;
-			} catch (IllegalConnectorArgumentsException e) {
+			} catch (IOException | IllegalConnectorArgumentsException e) {
 				fException = e;
 			}
 		}
@@ -192,14 +189,11 @@ public class StandardVMDebugger extends StandardVMRunner {
 
 		if (fVMInstance instanceof StandardVM && ((StandardVM)fVMInstance).getDebugArgs() != null){
 			String debugArgString = ((StandardVM)fVMInstance).getDebugArgs().replaceAll("\\Q" + StandardVM.VAR_PORT + "\\E", Integer.toString(port));  //$NON-NLS-1$ //$NON-NLS-2$
-			String[] debugArgs = DebugPlugin.parseArguments(debugArgString);
-			for (int i = 0; i < debugArgs.length; i++) {
-				arguments.add(debugArgs[i]);
-			}
+			arguments.addAll(Arrays.asList(DebugPlugin.parseArguments(debugArgString)));
 		} else {
 			// VM arguments are the first thing after the java program so that users can specify
 			// options like '-client' & '-server' which are required to be the first options
-			double version = getJavaVersion();
+			double version = getJavaVersion(fVMInstance);
 			if (version < 1.5) {
 				arguments.add("-Xdebug"); //$NON-NLS-1$
 				arguments.add("-Xnoagent"); //$NON-NLS-1$
@@ -209,6 +203,12 @@ public class StandardVMDebugger extends StandardVMRunner {
 			if (version < 1.4) {
 				arguments.add("-Djava.compiler=NONE"); //$NON-NLS-1$
 			}
+			// check if java 14 or greater
+			if (version >= 14) {
+				if (launch.getLaunchConfiguration().getAttribute(IJavaLaunchConfigurationConstants.ATTR_SHOW_CODEDETAILS_IN_EXCEPTION_MESSAGES, true)) {
+					arguments.add("-XX:+ShowCodeDetailsInExceptionMessages"); //$NON-NLS-1$
+				}
+			}
 			if (version < 1.5) {
 				arguments.add("-Xrunjdwp:transport=dt_socket,suspend=y,address=localhost:" + port); //$NON-NLS-1$
 			} else {
@@ -241,11 +241,7 @@ public class StandardVMDebugger extends StandardVMRunner {
 
 		String dependencies = config.getOverrideDependencies();
 		if (dependencies != null && dependencies.length() > 0) {
-			String[] parseArguments = DebugPlugin.parseArguments(dependencies);
-			for (String string : parseArguments) {
-				arguments.add(string);
-			}
-
+			arguments.addAll(Arrays.asList(DebugPlugin.parseArguments(dependencies)));
 		}
 
 		if (isModular(config, fVMInstance)) {
@@ -288,11 +284,17 @@ public class StandardVMDebugger extends StandardVMRunner {
 		}
 		subMonitor.worked(1);
 
+		CommandLineShortener commandLineShortener = new CommandLineShortener(fVMInstance, launch, newCmdLine, workingDir);
+		if (commandLineShortener.shouldShortenCommandLine()) {
+			cmdLine = commandLineShortener.shortenCommandLine();
+		}
+
 		CommandDetails cmd = new CommandDetails();
 		cmd.setCommandLine(cmdLine);
 		cmd.setEnvp(envp);
 		cmd.setWorkingDir(workingDir);
 		cmd.setClasspathShortener(classpathShortener);
+		cmd.setCommandLineShortener(commandLineShortener);
 		cmd.setPort(port);
 		return cmd;
 
@@ -364,8 +366,9 @@ public class StandardVMDebugger extends StandardVMRunner {
 					}
 					process.setAttribute(DebugPlugin.ATTR_ENVIRONMENT, buff.toString());
 				}
-				if (!cmdDetails.getClasspathShortener().getProcessTempFiles().isEmpty()) {
-					String tempFiles = cmdDetails.getClasspathShortener().getProcessTempFiles().stream().map(file -> file.getAbsolutePath()).collect(Collectors.joining(File.pathSeparator));
+				if (!cmdDetails.getClasspathShortener().getProcessTempFiles().isEmpty()
+						|| !cmdDetails.getCommandLineShortener().getProcessTempFiles().isEmpty()) {
+					String tempFiles = Stream.concat(cmdDetails.getClasspathShortener().getProcessTempFiles().stream(), cmdDetails.getCommandLineShortener().getProcessTempFiles().stream()).map(File::getAbsolutePath).collect(Collectors.joining(File.pathSeparator));
 					process.setAttribute(LaunchingPlugin.ATTR_LAUNCH_TEMP_FILES, tempFiles);
 				}
 				subMonitor.worked(1);
@@ -439,7 +442,7 @@ public class StandardVMDebugger extends StandardVMRunner {
 						}
 						Object result = handler.handleStatus(status, this);
 						if (result instanceof Boolean) {
-							retry = ((Boolean)result).booleanValue();
+							retry = ((Boolean)result);
 						}
 						if (!retry && retryCount < 5) {
 							retry = true;
@@ -501,16 +504,14 @@ public class StandardVMDebugger extends StandardVMRunner {
 				if(env == null){
 					Map<String, String> map = DebugPlugin.getDefault().getLaunchManager().getNativeEnvironment();
 					env = new String[map.size()];
-					String var = null;
 					int index = 0;
-					for(Iterator<String> iter = map.keySet().iterator(); iter.hasNext();) {
-						var = iter.next();
+					for (String var : map.keySet()) {
 						String value = map.get(var);
 						if (value == null) {
 							value = ""; //$NON-NLS-1$
 						}
 						if (var.equalsIgnoreCase("path")) { //$NON-NLS-1$
-							if(value.indexOf(jrestr) == -1) {
+							if (!value.contains(jrestr)) {
 								value = jrestr+';'+value;
 							}
 						}
@@ -553,38 +554,6 @@ public class StandardVMDebugger extends StandardVMRunner {
 		return JDIDebugModel.newDebugTarget(launch, vm, renderDebugTarget(config.getClassToLaunch(), port), process, true, false, config.isResumeOnStartup());
 	}
 
-	/**
-	 * Returns the version of the current VM in use
-	 * @return the VM version
-	 */
-	private double getJavaVersion() {
-		String version = null;
-		if (fVMInstance instanceof IVMInstall2) {
-			version = ((IVMInstall2)fVMInstance).getJavaVersion();
-		} else {
-			LibraryInfo libInfo = LaunchingPlugin.getLibraryInfo(fVMInstance.getInstallLocation().getAbsolutePath());
-			if (libInfo == null) {
-			    return 0D;
-			}
-			version = libInfo.getVersion();
-		}
-		if (version == null) {
-			// unknown version
-			return 0D;
-		}
-		int index = version.indexOf("."); //$NON-NLS-1$
-		int nextIndex = version.indexOf(".", index+1); //$NON-NLS-1$
-		try {
-			if (index > 0 && nextIndex>index) {
-				return Double.parseDouble(version.substring(0,nextIndex));
-			}
-			return Double.parseDouble(version);
-		} catch (NumberFormatException e) {
-			return 0D;
-		}
-
-	}
-
 	/**
 	 * Checks and forwards an error from the specified process
 	 * @param process the process to get the error message from
@@ -630,9 +599,7 @@ public class StandardVMDebugger extends StandardVMRunner {
 	 */
 	@SuppressWarnings("nls")
 	protected ListeningConnector getConnector() {
-		List<ListeningConnector> connectors= Bootstrap.virtualMachineManager().listeningConnectors();
-		for (int i= 0; i < connectors.size(); i++) {
-			ListeningConnector c= connectors.get(i);
+		for (ListeningConnector c : Bootstrap.virtualMachineManager().listeningConnectors()) {
 			if ("com.sun.jdi.SocketListen".equals(c.name())) {
 				return c;
 			}
