@@ -13,9 +13,9 @@
  *******************************************************************************/
 package org.eclipse.jdt.internal.launching;
 
-
 import java.io.File;
 import java.io.IOException;
+import java.text.DateFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Date;
@@ -24,6 +24,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
@@ -42,8 +43,6 @@ import org.eclipse.jdt.launching.JavaRuntime;
 import org.eclipse.jdt.launching.VMRunnerConfiguration;
 import org.eclipse.osgi.util.NLS;
 
-import com.ibm.icu.text.DateFormat;
-
 /**
  * A launcher for running Java main classes.
  */
@@ -109,9 +108,7 @@ public class StandardVMRunner extends AbstractVMRunner {
 		if (args == null) {
 			return;
 		}
-		for (int i= 0; i < args.length; i++) {
-			v.add(args[i]);
-		}
+		v.addAll(Arrays.asList(args));
 	}
 
 	/**
@@ -133,7 +130,7 @@ public class StandardVMRunner extends AbstractVMRunner {
 		catch(CoreException ce) {
 			LaunchingPlugin.log(ce);
 		}
-		return cmdLine;
+		return null;
 	}
 
 	/**
@@ -147,8 +144,8 @@ public class StandardVMRunner extends AbstractVMRunner {
 	 */
 	private String[] wrap(ILaunchConfiguration config, String[] cmdLine) throws CoreException {
 		if(config != null && Platform.OS_MACOSX.equals(Platform.getOS())) {
-			for (int i= 0; i < cmdLine.length; i++) {
-				if ("-ws".equals(cmdLine[i]) || cmdLine[i].indexOf("swt.jar") > -1 || cmdLine[i].indexOf("org.eclipse.swt") > -1) {   //$NON-NLS-1$//$NON-NLS-2$//$NON-NLS-3$
+			for (String element : cmdLine) {
+				if ("-ws".equals(element) || element.contains("swt.jar") || element.contains("org.eclipse.swt")) { //$NON-NLS-1$//$NON-NLS-2$//$NON-NLS-3$
 					return createSWTlauncher(cmdLine,
 							cmdLine[0],
 							config.getAttribute(IJavaLaunchConfigurationConstants.ATTR_USE_START_ON_FIRST_THREAD, true));
@@ -172,11 +169,11 @@ public class StandardVMRunner extends AbstractVMRunner {
 			// not started via java_swt -> now we require that the VM supports the "-XstartOnFirstThread" option
 			boolean found = false;
 			ArrayList<String> args = new ArrayList<>();
-			for (int i = 0; i < cmdLine.length; i++) {
-				if(XSTART_ON_FIRST_THREAD.equals(cmdLine[i])) {
+			for (String element : cmdLine) {
+				if(XSTART_ON_FIRST_THREAD.equals(element)) {
 					found = true;
 				}
-				args.add(cmdLine[i]);
+				args.add(element);
 			}
 			//newer VMs and non-MacOSX VMs don't like "-XstartOnFirstThread"
 			// see https://bugs.eclipse.org/bugs/show_bug.cgi?id=211625
@@ -191,9 +188,7 @@ public class StandardVMRunner extends AbstractVMRunner {
 			Process process= Runtime.getRuntime().exec(new String[] { "/bin/cp", java_swt, "/tmp" }); //$NON-NLS-1$ //$NON-NLS-2$
 			process.waitFor();
 			java_swt= "/tmp/java_swt"; //$NON-NLS-1$
-		} catch (IOException e) {
-			// ignore and run java_swt in place
-		} catch (InterruptedException e) {
+		} catch (IOException | InterruptedException e) {
 			// ignore and run java_swt in place
 		}
 		String[] newCmdLine= new String[cmdLine.length+1];
@@ -310,11 +305,11 @@ public class StandardVMRunner extends AbstractVMRunner {
 		if (cp.length == 0) {
 			return "";    //$NON-NLS-1$
 		}
-		for (int i= 0; i < cp.length; i++) {
+		for (String element : cp) {
 			if (pathCount > 0) {
 				buf.append(File.pathSeparator);
 			}
-			buf.append(cp[i]);
+			buf.append(element);
 			pathCount++;
 		}
 		return buf.toString();
@@ -332,8 +327,8 @@ public class StandardVMRunner extends AbstractVMRunner {
 	 */
 	protected String[] ensureEncoding(ILaunch launch, String[] vmargs) {
 		boolean foundencoding = false;
-		for(int i = 0; i < vmargs.length; i++) {
-			if(vmargs[i].startsWith("-Dfile.encoding=")) { //$NON-NLS-1$
+		for (String vmarg : vmargs) {
+			if(vmarg.startsWith("-Dfile.encoding=")) { //$NON-NLS-1$
 				foundencoding = true;
 			}
 		}
@@ -350,11 +345,12 @@ public class StandardVMRunner extends AbstractVMRunner {
 		return vmargs;
 	}
 
-	protected class CommandDetails {
+	protected static class CommandDetails {
 		private String[] commandLine;
 		private String[] envp;
 		private File workingDir;
 		private ClasspathShortener classpathShortener;
+		private CommandLineShortener commandLineShortener;
 		private int port;
 
 		public String[] getEnvp() {
@@ -389,6 +385,14 @@ public class StandardVMRunner extends AbstractVMRunner {
 			this.classpathShortener = classpathShortener;
 		}
 
+		public CommandLineShortener getCommandLineShortener() {
+			return commandLineShortener;
+		}
+
+		public void setCommandLineShortener(CommandLineShortener commandLineShortener) {
+			this.commandLineShortener = commandLineShortener;
+		}
+
 		public int getPort() {
 			return port;
 		}
@@ -444,13 +448,18 @@ public class StandardVMRunner extends AbstractVMRunner {
 			arguments.add("--enable-preview"); //$NON-NLS-1$
 		}
 
+		ILaunchConfiguration launchConfiguration = launch.getLaunchConfiguration();
+		// check if java 14 or greater
+		if (getJavaVersion(fVMInstance) >= 14) {
+			if (launchConfiguration != null
+					&& launchConfiguration.getAttribute(IJavaLaunchConfigurationConstants.ATTR_SHOW_CODEDETAILS_IN_EXCEPTION_MESSAGES, true)) {
+				arguments.add("-XX:+ShowCodeDetailsInExceptionMessages"); //$NON-NLS-1$
+			}
+		}
+
 		String dependencies = config.getOverrideDependencies();
 		if (dependencies != null && dependencies.length() > 0) {
-			String[] parseArguments = DebugPlugin.parseArguments(dependencies);
-			for (String string : parseArguments) {
-				arguments.add(string);
-			}
-
+			arguments.addAll(Arrays.asList(DebugPlugin.parseArguments(dependencies)));
 		}
 		if (isModular(config, fVMInstance)) {
 			arguments.add("-m"); //$NON-NLS-1$
@@ -472,15 +481,20 @@ public class StandardVMRunner extends AbstractVMRunner {
 			cmdLine = classpathShortener.getCmdLine();
 			envp = classpathShortener.getEnvp();
 		}
-		String[] newCmdLine = validateCommandLine(launch.getLaunchConfiguration(), cmdLine);
+		String[] newCmdLine = validateCommandLine(launchConfiguration, cmdLine);
 		if (newCmdLine != null) {
 			cmdLine = newCmdLine;
 		}
+		CommandLineShortener commandLineShortener = new CommandLineShortener(fVMInstance, launch, newCmdLine, workingDir);
+		if (commandLineShortener.shouldShortenCommandLine()) {
+			cmdLine = commandLineShortener.shortenCommandLine();
+		}
 		CommandDetails cmd = new CommandDetails();
 		cmd.setCommandLine(cmdLine);
 		cmd.setEnvp(envp);
 		cmd.setWorkingDir(workingDir);
 		cmd.setClasspathShortener(classpathShortener);
+		cmd.setCommandLineShortener(commandLineShortener);
 		subMonitor.worked(1);
 		return cmd;
 	}
@@ -521,17 +535,11 @@ public class StandardVMRunner extends AbstractVMRunner {
 		if (cmdDetails.getEnvp() != null) {
 			String[] envp = cmdDetails.getEnvp();
 			Arrays.sort(envp);
-			StringBuilder buff = new StringBuilder();
-			for (int i = 0; i < envp.length; i++) {
-				buff.append(envp[i]);
-				if(i < envp.length-1) {
-					buff.append('\n');
-				}
-			}
-			process.setAttribute(DebugPlugin.ATTR_ENVIRONMENT, buff.toString());
+			process.setAttribute(DebugPlugin.ATTR_ENVIRONMENT, String.join(String.valueOf('\n'), envp));
 		}
-		if (!cmdDetails.getClasspathShortener().getProcessTempFiles().isEmpty()) {
-			String tempFiles = cmdDetails.getClasspathShortener().getProcessTempFiles().stream().map(file -> file.getAbsolutePath()).collect(Collectors.joining(File.pathSeparator));
+		if (!cmdDetails.getClasspathShortener().getProcessTempFiles().isEmpty()
+				|| !cmdDetails.getCommandLineShortener().getProcessTempFiles().isEmpty()) {
+			String tempFiles = Stream.concat(cmdDetails.getClasspathShortener().getProcessTempFiles().stream(), cmdDetails.getCommandLineShortener().getProcessTempFiles().stream()).map(File::getAbsolutePath).collect(Collectors.joining(File.pathSeparator));
 			process.setAttribute(LaunchingPlugin.ATTR_LAUNCH_TEMP_FILES, tempFiles);
 		}
 		subMonitor.worked(1);
@@ -646,4 +654,36 @@ public class StandardVMRunner extends AbstractVMRunner {
 		}
 	}
 
+	/**
+	 * Returns the version of the current VM in use
+	 * @return the VM version
+	 */
+	protected double getJavaVersion(IVMInstall fVMInstance) {
+		String version = null;
+		if (fVMInstance instanceof IVMInstall2) {
+			version = ((IVMInstall2)fVMInstance).getJavaVersion();
+		} else {
+			LibraryInfo libInfo = LaunchingPlugin.getLibraryInfo(fVMInstance.getInstallLocation().getAbsolutePath());
+			if (libInfo == null) {
+			    return 0D;
+			}
+			version = libInfo.getVersion();
+		}
+		if (version == null) {
+			// unknown version
+			return 0D;
+		}
+		int index = version.indexOf("."); //$NON-NLS-1$
+		int nextIndex = version.indexOf(".", index+1); //$NON-NLS-1$
+		try {
+			if (index > 0 && nextIndex>index) {
+				return Double.parseDouble(version.substring(0,nextIndex));
+			}
+			return Double.parseDouble(version);
+		} catch (NumberFormatException e) {
+			return 0D;
+		}
+
+	}
+
 }
