@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -480,14 +480,16 @@ public class StandardVMType extends AbstractVMInstallType {
 				IPath pathName = new Path(installLocation.getAbsolutePath()).append(LIB).append(JRT_FS_JAR);
 				// From Java 9 149 version, we see that jrt-fs.jar is moved to lib directory so we need to look at both places
 				File jrtfsJar = pathName.toFile();
-				if (!jrtfsJar.exists()) {
+				boolean exists = jrtfsJar.exists();
+				if (!exists) {
 					pathName = new Path(installLocation.getAbsolutePath()).append(JRT_FS_JAR);
+					exists = pathName.toFile().exists();
 				}
 
-				LibraryLocation libraryLocation = new LibraryLocation(pathName,
-						sourceRootPath, getDefaultPackageRootPath(),
-						getDefaultJavadocLocation(installLocation));
-				allLibs.add(libraryLocation);
+				if (exists) {
+					LibraryLocation libraryLocation = new LibraryLocation(pathName, sourceRootPath, getDefaultPackageRootPath(), getDefaultJavadocLocation(installLocation));
+					allLibs.add(libraryLocation);
+				}
 			}
 
 			// next is the boot path libraries
@@ -844,7 +846,15 @@ public class StandardVMType extends AbstractVMInstallType {
 	 */
 	public static URL getDefaultJavadocLocation(String version) {
 		try {
-			if (version.startsWith(JavaCore.VERSION_12)) {
+			if (version.startsWith(JavaCore.VERSION_16)) {
+				return new URL("https://docs.oracle.com/en/java/javase/16/docs/api/"); //$NON-NLS-1$
+			} else if (version.startsWith(JavaCore.VERSION_15)) {
+				return new URL("https://docs.oracle.com/en/java/javase/15/docs/api/"); //$NON-NLS-1$
+			} else if (version.startsWith(JavaCore.VERSION_14)) {
+				return new URL("https://docs.oracle.com/en/java/javase/14/docs/api/"); //$NON-NLS-1$
+			} else if (version.startsWith(JavaCore.VERSION_13)) {
+				return new URL("https://docs.oracle.com/en/java/javase/13/docs/api/"); //$NON-NLS-1$
+			} else if (version.startsWith(JavaCore.VERSION_12)) {
 				return new URL("https://docs.oracle.com/en/java/javase/12/docs/api/"); //$NON-NLS-1$
 			} else if (version.startsWith(JavaCore.VERSION_11)) {
 				return new URL("https://docs.oracle.com/en/java/javase/11/docs/api/"); //$NON-NLS-1$
